==> emodpy_covid-0.0.30-py3-none-any.whl: emodpy_covid/post/dtk_post_process_newinf_sql2csv.py <==
#!/usr/bin/python

import json
import sqlite3
import pdb
import csv

def app( output_path ):
    # Do SQL query against simulation.db (?) and look for any NewlySymptomatic events this timestep
    # If there are any, for each individual, do a query for any NewInfection events within last 5 days
    # where the infector id == the id of the newly symptomatic individual.
    # Create a new campaign file which distributes SimpleVaccine to those individuals.
    # This will require creation of new method to target interventions by individual id

    # CREATE TABLE SIM_EVENTS (SIM_TIME       INT    NOT NULL,EVENT          TEXT     NOT NULL,INDIVIDUAL     INT    NOT NULL,MISC           INT    NOT NULL);

    infections = []
    infection = {}
    with sqlite3.connect('simulation_events.db') as conn:
        cur = conn.cursor() 
        query = "SELECT SIM_TIME, INDIVIDUAL, MISC, NOTES from SIM_EVENTS where EVENT=='NewInfection';"
        cur.execute( query )
        rows = cur.fetchall()
        for row in rows:
            time = row[0]
            individual = row[1]
            infector = row[2]
            ip_info = row[3]
            infection = { "Time": time, "Individual": individual, "Infector": infector, "IP": ip_info }
            infections.append( infection ) 

    with open( "new_infections.csv", 'w' ) as datafile:
        mywriter = csv.DictWriter( datafile,fieldnames=["Time","Individual","Infector","IP"] )
        mywriter.writeheader()
        for idx in range(len(infections)):
            mywriter.writerow( {'Time': infections[idx]['Time'], 'Individual': infections[idx]["Individual"], 'Infector': infections[idx]["Infector"], 'IP': infections[idx]["IP"]} )

    return ""

==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/post/dtk_post_process_newinf_sql2csv.py <==
#!/usr/bin/python

import json
import sqlite3
import os
import csv

def app( output_path ):
    # Do SQL query against simulation.db (?) and look for any NewlySymptomatic events this timestep
    # If there are any, for each individual, do a query for any NewInfection events within last 5 days
    # where the infector id == the id of the newly symptomatic individual.
    # Create a new campaign file which distributes SimpleVaccine to those individuals.
    # This will require creation of new method to target interventions by individual id

    # CREATE TABLE SIM_EVENTS (SIM_TIME       INT    NOT NULL,EVENT          TEXT     NOT NULL,INDIVIDUAL     INT    NOT NULL,MISC           INT    NOT NULL);

    infections = []
    infection = {}
    with sqlite3.connect('simulation_events.db') as conn:
        cur = conn.cursor() 
        query = "SELECT SIM_TIME, INDIVIDUAL, MISC, NOTES from SIM_EVENTS where EVENT=='NewInfection';"
        cur.execute( query )
        rows = cur.fetchall()
        for row in rows:
            time = row[0]
            individual = row[1]
            infector = row[2]
            ip_info = row[3]
            infection = { "Time": time, "Individual": individual, "Infector": infector, "IP": ip_info }
            infections.append( infection ) 

    with open( os.path.join( output_path, "new_infections.csv" ), 'w' ) as datafile:
        mywriter = csv.DictWriter( datafile,fieldnames=["Time","Individual","Infector","IP"] )
        mywriter.writeheader()
        for idx in range(len(infections)):
            mywriter.writerow( {'Time': infections[idx]['Time'], 'Individual': infections[idx]["Individual"], 'Infector': infections[idx]["Infector"], 'IP': infections[idx]["IP"]} )

    return ""
